User prompt
Add green platforms that make you go faster if you touch them for 20 seconds βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add turrets that shoot that shoot you with homing missiles and if the missile touches the floor or a platform it explodes βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add drones that shoot red cubes to attack you in the sky βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add Saws
User prompt
Please fix the bug: 'TypeError: setTimeout is not a function' in or related to this line: 'setTimeout(function () {' Line Number: 529
User prompt
Make the blue cube has facial expressions on the eyes βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add particles when the blue cube moves βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add moveable boxes
User prompt
Add sprinting
User prompt
Add spinning obstacles βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Add lasers
User prompt
Add the obstacle wall
User prompt
Remove the big red cube
User prompt
Make a new enemies that is a big red cube that jumps toward you to attack
User prompt
Make the blue cube be able to dash βͺπ‘ Consider importing and using the following plugins: @upit/tween.v1
User prompt
Make it so that the blue cube can double jump
User prompt
Make the platforms collidable
Code edit (1 edits merged)
Please save this source code
User prompt
Junkyard Journey
Initial prompt
Make a platformer game about a blue cube with eyes exploring the junkyard with enemies trying to kill the blue cube, the blue cube must get to the blue circle at the other side of the junkyard
/****
* Plugins
****/
var tween = LK.import("@upit/tween.v1");
/****
* Classes
****/
var Enemy = Container.expand(function () {
var self = Container.call(this);
var enemyBody = self.attachAsset('enemy', {
anchorX: 0.5,
anchorY: 1.0
});
self.speed = 2;
self.direction = 1;
self.startX = 0;
self.patrolDistance = 300;
self.update = function () {
self.x += self.speed * self.direction;
if (Math.abs(self.x - self.startX) > self.patrolDistance) {
self.direction *= -1;
}
// Ground collision for enemies
if (self.y >= groundLevel) {
self.y = groundLevel;
}
// Platform collision for enemies
for (var i = 0; i < platforms.length; i++) {
var platform = platforms[i];
// Check if enemy is on top of platform
if (self.intersects(platform)) {
var platformLeft = platform.x - 100; // platform width/2
var platformRight = platform.x + 100; // platform width/2
var platformTop = platform.y - 20; // platform height/2
var enemyLeft = self.x - 30; // enemy width/2
var enemyRight = self.x + 30; // enemy width/2
var enemyBottom = self.y;
// Landing on platform
if (enemyBottom > platformTop && enemyBottom < platformTop + 50 && enemyRight > platformLeft && enemyLeft < platformRight) {
self.y = platformTop;
}
}
}
};
return self;
});
var JunkPile = Container.expand(function () {
var self = Container.call(this);
var junkBody = self.attachAsset('junkPile', {
anchorX: 0.5,
anchorY: 1.0
});
return self;
});
var Platform = Container.expand(function () {
var self = Container.call(this);
var platformBody = self.attachAsset('platform', {
anchorX: 0.5,
anchorY: 0.5
});
return self;
});
var Player = Container.expand(function () {
var self = Container.call(this);
var playerBody = self.attachAsset('player', {
anchorX: 0.5,
anchorY: 1.0
});
var leftEye = self.attachAsset('playerEye', {
anchorX: 0.5,
anchorY: 0.5,
x: -20,
y: -50
});
var rightEye = self.attachAsset('playerEye', {
anchorX: 0.5,
anchorY: 0.5,
x: 20,
y: -50
});
var leftPupil = self.attachAsset('playerPupil', {
anchorX: 0.5,
anchorY: 0.5,
x: -20,
y: -50
});
var rightPupil = self.attachAsset('playerPupil', {
anchorX: 0.5,
anchorY: 0.5,
x: 20,
y: -50
});
self.velocityX = 0;
self.velocityY = 0;
self.onGround = false;
self.jumpCount = 0;
self.maxJumps = 2;
self.jumpPower = -15;
self.gravity = 0.8;
self.maxSpeed = 8;
self.friction = 0.85;
self.dashPower = 20;
self.dashDuration = 200;
self.dashCooldown = 1000;
self.isDashing = false;
self.dashTimeRemaining = 0;
self.lastDashTime = 0;
self.update = function () {
// Handle dash mechanics
if (self.isDashing && self.dashTimeRemaining > 0) {
self.dashTimeRemaining -= 16; // Assuming 60fps, ~16ms per frame
if (self.dashTimeRemaining <= 0) {
self.isDashing = false;
}
}
// Apply gravity (reduced during dash)
if (!self.isDashing) {
self.velocityY += self.gravity;
} else {
self.velocityY += self.gravity * 0.3; // Reduced gravity during dash
}
// Apply friction
self.velocityX *= self.friction;
// Update position
self.x += self.velocityX;
self.y += self.velocityY;
// Ground collision
if (self.y >= groundLevel) {
self.y = groundLevel;
self.velocityY = 0;
self.onGround = true;
self.jumpCount = 0;
} else {
self.onGround = false;
}
// Platform collision
for (var i = 0; i < platforms.length; i++) {
var platform = platforms[i];
// Check if player is intersecting with platform
if (self.intersects(platform)) {
// Calculate platform boundaries
var platformLeft = platform.x - 100; // platform width/2
var platformRight = platform.x + 100; // platform width/2
var platformTop = platform.y - 20; // platform height/2
var platformBottom = platform.y + 20; // platform height/2
var playerLeft = self.x - 40; // player width/2
var playerRight = self.x + 40; // player width/2
var playerTop = self.y - 80; // player height
var playerBottom = self.y;
// Landing on top of platform
if (self.velocityY > 0 && playerBottom > platformTop && playerTop < platformTop && playerRight > platformLeft && playerLeft < platformRight) {
self.y = platformTop;
self.velocityY = 0;
self.onGround = true;
self.jumpCount = 0;
}
// Hitting platform from below
else if (self.velocityY < 0 && playerTop < platformBottom && playerBottom > platformBottom && playerRight > platformLeft && playerLeft < platformRight) {
self.y = platformBottom + 80;
self.velocityY = 0;
}
// Hitting platform from left
else if (self.velocityX > 0 && playerRight > platformLeft && playerLeft < platformLeft && playerBottom > platformTop && playerTop < platformBottom) {
self.x = platformLeft - 40;
self.velocityX = 0;
}
// Hitting platform from right
else if (self.velocityX < 0 && playerLeft < platformRight && playerRight > platformRight && playerBottom > platformTop && playerTop < platformBottom) {
self.x = platformRight + 40;
self.velocityX = 0;
}
}
}
// Boundary checking
if (self.x < 40) {
self.x = 40;
}
if (self.x > levelWidth - 40) {
self.x = levelWidth - 40;
}
};
self.jump = function () {
if (self.jumpCount < self.maxJumps) {
self.velocityY = self.jumpPower;
self.jumpCount++;
self.onGround = false;
LK.getSound('jump').play();
}
};
self.moveLeft = function () {
self.velocityX = Math.max(self.velocityX - 1.5, -self.maxSpeed);
};
self.moveRight = function () {
self.velocityX = Math.min(self.velocityX + 1.5, self.maxSpeed);
};
self.dash = function (direction) {
var currentTime = Date.now();
if (currentTime - self.lastDashTime >= self.dashCooldown && !self.isDashing) {
self.isDashing = true;
self.dashTimeRemaining = self.dashDuration;
self.lastDashTime = currentTime;
// Apply dash velocity
self.velocityX = self.dashPower * direction;
// Visual dash effect with tween
tween(self, {
scaleX: 1.3,
scaleY: 0.8
}, {
duration: 100,
easing: tween.easeOut,
onFinish: function onFinish() {
tween(self, {
scaleX: 1,
scaleY: 1
}, {
duration: 100,
easing: tween.easeIn
});
}
});
// Flash effect during dash
tween(self, {
alpha: 0.7
}, {
duration: self.dashDuration / 2,
easing: tween.easeInOut,
onFinish: function onFinish() {
tween(self, {
alpha: 1
}, {
duration: self.dashDuration / 2,
easing: tween.easeInOut
});
}
});
}
};
return self;
});
var SpinningObstacle = Container.expand(function () {
var self = Container.call(this);
var obstacleBody = self.attachAsset('spinningObstacle', {
anchorX: 0.5,
anchorY: 0.5
});
// Start continuous spinning animation
self.startSpinning = function () {
tween(self, {
rotation: Math.PI * 2
}, {
duration: 2000,
easing: tween.linear,
onFinish: function onFinish() {
self.rotation = 0; // Reset rotation to avoid overflow
self.startSpinning(); // Continue spinning
}
});
};
return self;
});
/****
* Initialize Game
****/
var game = new LK.Game({
backgroundColor: 0x2C3E50
});
/****
* Game Code
****/
var player;
var enemies = [];
var platforms = [];
var junkPiles = [];
var spinningObstacles = [];
var goal;
var camera;
var groundLevel = 2600;
var levelWidth = 4000;
var gameWon = false;
// Create camera object for following player
camera = {
x: 0,
y: 0,
targetX: 0,
targetY: 0,
smoothing: 0.1
};
// Create player
player = game.addChild(new Player());
player.x = 200;
player.y = groundLevel;
// Create platforms
var platformPositions = [{
x: 500,
y: 2400
}, {
x: 800,
y: 2200
}, {
x: 1200,
y: 2300
}, {
x: 1600,
y: 2100
}, {
x: 2000,
y: 2000
}, {
x: 2400,
y: 2200
}, {
x: 2800,
y: 2400
}, {
x: 3200,
y: 2300
}, {
x: 3600,
y: 2500
}];
for (var i = 0; i < platformPositions.length; i++) {
var platform = game.addChild(new Platform());
platform.x = platformPositions[i].x;
platform.y = platformPositions[i].y;
platforms.push(platform);
}
// Create enemies
var enemyPositions = [{
x: 600,
y: groundLevel
}, {
x: 1000,
y: 2200
}, {
x: 1400,
y: groundLevel
}, {
x: 1800,
y: 2000
}, {
x: 2200,
y: groundLevel
}, {
x: 2600,
y: 2200
}, {
x: 3000,
y: groundLevel
}, {
x: 3400,
y: 2300
}];
for (var i = 0; i < enemyPositions.length; i++) {
var enemy = game.addChild(new Enemy());
enemy.x = enemyPositions[i].x;
enemy.y = enemyPositions[i].y;
enemy.startX = enemy.x;
enemies.push(enemy);
}
// Create junk piles for decoration
var junkPositions = [{
x: 300,
y: groundLevel
}, {
x: 700,
y: groundLevel
}, {
x: 1100,
y: groundLevel
}, {
x: 1500,
y: groundLevel
}, {
x: 1900,
y: groundLevel
}, {
x: 2300,
y: groundLevel
}, {
x: 2700,
y: groundLevel
}, {
x: 3100,
y: groundLevel
}, {
x: 3500,
y: groundLevel
}];
for (var i = 0; i < junkPositions.length; i++) {
var junk = game.addChild(new JunkPile());
junk.x = junkPositions[i].x;
junk.y = junkPositions[i].y;
junkPiles.push(junk);
}
// Create spinning obstacles
var spinningObstaclePositions = [{
x: 650,
y: 2350
}, {
x: 950,
y: 2150
}, {
x: 1350,
y: 2250
}, {
x: 1750,
y: 2050
}, {
x: 2150,
y: 1950
}, {
x: 2550,
y: 2150
}, {
x: 2950,
y: 2350
}, {
x: 3350,
y: 2250
}];
for (var i = 0; i < spinningObstaclePositions.length; i++) {
var spinningObstacle = game.addChild(new SpinningObstacle());
spinningObstacle.x = spinningObstaclePositions[i].x;
spinningObstacle.y = spinningObstaclePositions[i].y;
spinningObstacle.startSpinning();
spinningObstacles.push(spinningObstacle);
}
// Create goal
goal = game.addChild(LK.getAsset('goal', {
anchorX: 0.5,
anchorY: 0.5
}));
goal.x = levelWidth - 200;
goal.y = groundLevel - 50;
// Touch controls
var touchStartX = 0;
var touchStartY = 0;
var isDragging = false;
game.down = function (x, y, obj) {
touchStartX = x;
touchStartY = y;
isDragging = true;
// Jump on tap
player.jump();
};
game.move = function (x, y, obj) {
if (isDragging) {
var deltaX = x - touchStartX;
var deltaY = Math.abs(y - touchStartY);
// Check for dash gesture (fast horizontal swipe)
if (Math.abs(deltaX) > 100 && deltaY < 50) {
var dashDirection = deltaX > 0 ? 1 : -1;
player.dash(dashDirection);
isDragging = false; // End drag to prevent continuous movement
}
// Regular movement for smaller gestures
else if (deltaX < -20) {
player.moveLeft();
} else if (deltaX > 20) {
player.moveRight();
}
}
};
game.up = function (x, y, obj) {
isDragging = false;
};
// Game update loop
game.update = function () {
if (gameWon) return;
// Update camera to follow player
camera.targetX = player.x - 1024;
camera.targetY = player.y - 1366;
camera.x += (camera.targetX - camera.x) * camera.smoothing;
camera.y += (camera.targetY - camera.y) * camera.smoothing;
// Keep camera within level bounds
if (camera.x < 0) camera.x = 0;
if (camera.x > levelWidth - 2048) camera.x = levelWidth - 2048;
if (camera.y < -500) camera.y = -500;
if (camera.y > 0) camera.y = 0;
// Apply camera offset to game
game.x = -camera.x;
game.y = -camera.y;
// Check collision with enemies
for (var i = 0; i < enemies.length; i++) {
var enemy = enemies[i];
if (player.intersects(enemy)) {
LK.getSound('hit').play();
LK.effects.flashScreen(0xFF0000, 500);
LK.setTimeout(function () {
LK.showGameOver();
}, 500);
return;
}
}
// Check collision with spinning obstacles
for (var i = 0; i < spinningObstacles.length; i++) {
var obstacle = spinningObstacles[i];
if (player.intersects(obstacle)) {
LK.getSound('hit').play();
LK.effects.flashScreen(0xFF0000, 500);
LK.setTimeout(function () {
LK.showGameOver();
}, 500);
return;
}
}
// Check if player reached goal
if (player.intersects(goal)) {
gameWon = true;
LK.effects.flashScreen(0x00FF00, 1000);
LK.setTimeout(function () {
LK.showYouWin();
}, 1000);
return;
}
// Check if player fell off the level
if (player.y > groundLevel + 500) {
LK.effects.flashScreen(0xFF0000, 500);
LK.setTimeout(function () {
LK.showGameOver();
}, 500);
return;
}
}; ===================================================================
--- original.js
+++ change.js
@@ -52,60 +52,8 @@
anchorY: 1.0
});
return self;
});
-var Laser = Container.expand(function () {
- var self = Container.call(this);
- var laserBeam = self.attachAsset('laser', {
- anchorX: 0.0,
- anchorY: 0.5
- });
- self.speed = 12;
- self.direction = 1; // 1 for right, -1 for left
- self.active = false;
- self.chargeTime = 0;
- self.maxChargeTime = 120; // 2 seconds at 60fps
- self.fireTime = 0;
- self.maxFireTime = 180; // 3 seconds at 60fps
- self.cooldownTime = 0;
- self.maxCooldownTime = 240; // 4 seconds at 60fps
- self.state = 'charging'; // 'charging', 'firing', 'cooldown'
- // Initially invisible
- laserBeam.alpha = 0;
- self.update = function () {
- if (self.state === 'charging') {
- self.chargeTime++;
- // Flashing warning effect
- var flashIntensity = Math.sin(self.chargeTime * 0.3) * 0.5 + 0.5;
- laserBeam.alpha = flashIntensity * 0.3;
- if (self.chargeTime >= self.maxChargeTime) {
- self.state = 'firing';
- self.fireTime = 0;
- self.active = true;
- laserBeam.alpha = 1;
- LK.getSound('laser').play();
- }
- } else if (self.state === 'firing') {
- self.fireTime++;
- self.active = true;
- if (self.fireTime >= self.maxFireTime) {
- self.state = 'cooldown';
- self.cooldownTime = 0;
- self.active = false;
- laserBeam.alpha = 0;
- }
- } else if (self.state === 'cooldown') {
- self.cooldownTime++;
- self.active = false;
- laserBeam.alpha = 0;
- if (self.cooldownTime >= self.maxCooldownTime) {
- self.state = 'charging';
- self.chargeTime = 0;
- }
- }
- };
- return self;
-});
var Platform = Container.expand(function () {
var self = Container.call(this);
var platformBody = self.attachAsset('platform', {
anchorX: 0.5,
@@ -289,8 +237,29 @@
}
};
return self;
});
+var SpinningObstacle = Container.expand(function () {
+ var self = Container.call(this);
+ var obstacleBody = self.attachAsset('spinningObstacle', {
+ anchorX: 0.5,
+ anchorY: 0.5
+ });
+ // Start continuous spinning animation
+ self.startSpinning = function () {
+ tween(self, {
+ rotation: Math.PI * 2
+ }, {
+ duration: 2000,
+ easing: tween.linear,
+ onFinish: function onFinish() {
+ self.rotation = 0; // Reset rotation to avoid overflow
+ self.startSpinning(); // Continue spinning
+ }
+ });
+ };
+ return self;
+});
/****
* Initialize Game
****/
@@ -304,9 +273,9 @@
var player;
var enemies = [];
var platforms = [];
var junkPiles = [];
-var lasers = [];
+var spinningObstacles = [];
var goal;
var camera;
var groundLevel = 2600;
var levelWidth = 4000;
@@ -425,41 +394,40 @@
junk.x = junkPositions[i].x;
junk.y = junkPositions[i].y;
junkPiles.push(junk);
}
-// Create lasers
-var laserPositions = [{
- x: 100,
- y: 2500
+// Create spinning obstacles
+var spinningObstaclePositions = [{
+ x: 650,
+ y: 2350
}, {
- x: 900,
- y: 2300
+ x: 950,
+ y: 2150
}, {
- x: 1300,
- y: 2400
+ x: 1350,
+ y: 2250
}, {
- x: 1700,
+ x: 1750,
+ y: 2050
+}, {
+ x: 2150,
+ y: 1950
+}, {
+ x: 2550,
y: 2150
}, {
- x: 2100,
+ x: 2950,
y: 2350
}, {
- x: 2500,
+ x: 3350,
y: 2250
-}, {
- x: 2900,
- y: 2450
-}, {
- x: 3300,
- y: 2350
}];
-for (var i = 0; i < laserPositions.length; i++) {
- var laser = game.addChild(new Laser());
- laser.x = laserPositions[i].x;
- laser.y = laserPositions[i].y;
- // Stagger the charging times so they don't all fire at once
- laser.chargeTime = i * 30;
- lasers.push(laser);
+for (var i = 0; i < spinningObstaclePositions.length; i++) {
+ var spinningObstacle = game.addChild(new SpinningObstacle());
+ spinningObstacle.x = spinningObstaclePositions[i].x;
+ spinningObstacle.y = spinningObstaclePositions[i].y;
+ spinningObstacle.startSpinning();
+ spinningObstacles.push(spinningObstacle);
}
// Create goal
goal = game.addChild(LK.getAsset('goal', {
anchorX: 0.5,
@@ -526,12 +494,12 @@
}, 500);
return;
}
}
- // Check collision with active lasers
- for (var i = 0; i < lasers.length; i++) {
- var laser = lasers[i];
- if (laser.active && player.intersects(laser)) {
+ // Check collision with spinning obstacles
+ for (var i = 0; i < spinningObstacles.length; i++) {
+ var obstacle = spinningObstacles[i];
+ if (player.intersects(obstacle)) {
LK.getSound('hit').play();
LK.effects.flashScreen(0xFF0000, 500);
LK.setTimeout(function () {
LK.showGameOver();